@@ -346,8 +346,8 @@ build_new_source (GdictSourceDialog *dialog)
     }
       
   name = g_strdup_printf ("%s.desktop", gdict_source_get_name (source));
-  filename = g_build_filename (g_get_home_dir (),
-  			       ".mate2",
+  filename = g_build_filename (g_get_user_config_dir (),
+  			       "mate",
       			       "mate-dictionary",
       			       name,
       			       NULL);
@@ -439,8 +439,8 @@ save_source (GdictSourceDialog *dialog)
     }
       
   name = g_strdup_printf ("%s.desktop", gdict_source_get_name (source));
-  filename = g_build_filename (g_get_home_dir (),
-      			       ".mate2",
+  filename = g_build_filename (g_get_user_config_dir (),
+      			       "mate",
 			       "mate-dictionary",
 			       name,
 			       NULL);
